@@ -167,7 +167,11 @@ chroot_config::add_config_directory (std::string const& chroot_namespace,
        dirent != end_iter;
        ++dirent)
     {
+#if !defined(BOOST_FILESYSTEM_VERSION) || BOOST_FILESYSTEM_VERSION == 2
       std::string name(dirent->leaf());
+#else
+      std::string name(dirent->path().filename().string());
+#endif
 
       // Skip common directories.
       if (name == "." || name == "..")
